@@ -1,7 +1,7 @@
 """Init for utils."""
 from .graph_utils import load_graph, pb_to_tensorboard_event, freeze_session, freeze_graph_from_ckpt, wrap_frozen_graph
 from .graph_utils import freeze_keras_model
-from .tf_runner import TFRunner
+from .tf_runner import TFRunner, get_original_node_names_from_cfg
 from .runner import Runner
 
 __all__ = [
@@ -13,7 +13,8 @@ __all__ = [
     'freeze_graph_from_ckpt',
     'wrap_frozen_graph',
     'TFRunner',
-    'freeze_keras_model'
+    'freeze_keras_model',
+    'get_original_node_names_from_cfg'
 ]
 
 try:
